@@ -30,7 +30,7 @@ use constant  AWS_CONTAINER_CREDENTIALS_URL          => 'http://169.254.170.2';
 
 use vars qw/$VERSION @EXPORT/;
 
-$VERSION = '1.0.12'; $VERSION=~s/\-.*$//;
+$VERSION = '1.0.13'; $VERSION=~s/\-.*$//;
 
 @EXPORT = qw/$VERSION/;
 
@@ -213,9 +213,8 @@ sub new {
 
   if ( !$self->get_logger ) {
     $self->set_logger(bless { debug => $self->get_debug }, 'Amazon::Credentials::Logger');
+    $self->get_logger->debug("WARNING: DEBUG mode using default logger");
   }
-
-  $self->get_logger->debug("debug is on\n");
   
   if ( !$self->get_user_agent) {
     # set a very low timeout
@@ -317,8 +316,6 @@ sub find_credentials {
   my $self    = shift;
   my %options = ref( $_[0] ) ? %{ $_[0] } : @_;
 
-  $self->get_logger->debug("find credentials\n");
-  
   $options{order}   = $self->get_order  || [qw/env role container file/];
   $options{profile} = $options{profile} || $self->get_profile;
 
@@ -330,7 +327,6 @@ sub find_credentials {
   my @order = @{ $options{order} };
 
   foreach my $location (@order) {
-    $self->get_logger->debug("looking for credentials in $location\n");
     
     if ( $location eq 'env' ) {
       if ( $ENV{AWS_ACCESS_KEY_ID} && $ENV{AWS_SECRET_ACCESS_KEY} ) {
@@ -343,7 +339,6 @@ sub find_credentials {
     } ## end if ( $location eq 'env')
     elsif ( $location eq 'container' ) {
       $creds = $self->get_creds_from_container();
-      $self->get_logger->debug(Dumper [$creds]);
     }
     elsif ( $location eq 'role' ) {
       $creds = $self->get_creds_from_role();
@@ -359,9 +354,7 @@ sub find_credentials {
         my $profile_name = $options{profile};
 
         local $CWD = home;
-        
-        $self->get_logger->debug("home: [" . $CWD . "]\n");
-        
+
         next unless -e $config;
 
         open my $fh, '<', $config
@@ -374,8 +367,6 @@ sub find_credentials {
         while (my $current_line = <$fh>) {
           chomp $current_line;
 
-          $self->get_logger->debug("line: $current_line\n");
-          
           # once we find a profile section that matches, undef it
           # ./aws/credentials uses [profile-name]
           # ./aws/config uses [profile profile-name]
@@ -421,8 +412,6 @@ sub find_credentials {
 
         close $fh;
 
-        $self->get_logger->debug( Dumper [$creds] );
-
         $creds->{source} = $config
           if $creds->{aws_secret_access_key} && $creds->{aws_access_key_id};
       } ## end foreach my $config ( ".aws/config"...)
@@ -464,8 +453,6 @@ sub is_token_expired {
     # AWS recommends getting credentials 5 minutes prior to expiration
     my $g = _iso8601_to_time($expiration_date);
     
-    $self->get_logger->debug("gmt time in seconds: $g\n");
-
     # shave 5 minutes or window interval off of the expiration time
     $g -= $window_interval * 60;
 
@@ -619,8 +606,6 @@ sub refresh_token {
     $creds = $self->get_creds_from_role;
   }
 
-  $self->get_logger->debug(Dumper [$creds]);
-
   croak 'unable to refresh token!'
     if !ref($creds) || !keys %$creds;
   
